@@ -14,7 +14,7 @@
 #'
 #'
 #'@param proxy Use TRUE if connecting through a proxy. This invokes
-#'\code{\link{setInternet2}}
+#'\code{setInternet2} - only works on Windows.
 #'@author QuasiMC by Mik Cieslak, R installation code by Remko Duursma.
 #'@references Cieslak, M., C. Lemieux, J. Hanan and P. Prusinkiewicz. 2008.
 #'Quasi-Monte Carlo simulation of the light environment of plants. Functional
@@ -25,7 +25,6 @@
 #'@export
 installQuasiMC <- function(proxy=FALSE){
 
-        # MC 2/12/2012 - updated to include install for Mac OS X
 	if(.Platform$OS.type == "windows"){
 		
 		if(!file.exists("c:/QuasiMC")){
@@ -33,7 +32,7 @@ installQuasiMC <- function(proxy=FALSE){
 			message("Created the directory : c:/QuasiMC")
 		}
 
-		if(proxy)setInternet2(TRUE)
+		if(proxy)utils::setInternet2(TRUE)
 		
 		if(file.exists("c:/quasimc/QuasiMC.zip")){
 			message("Updating existing QuasiMC installation.")
@@ -43,19 +42,18 @@ installQuasiMC <- function(proxy=FALSE){
 			"c:/quasimc/QuasiMC.zip")
 		unzip("c:/quasimc/QuasiMC.zip", exdir="C:/quasimc")
 		message("'QuasiMC.exe' and 'enviro.e' have been placed in the folder 'c:/QuasiMC'.\n  !- Please do not rename or move!\n")
-	} else if (Sys.info()[['sysname']] == "Darwin") {
 
-               qmc_dir = paste(path.expand("~"),"/QuasiMC/",sep="")
-               qmc_tgz = "QuasiMC_Mac.tgz"
-               qmc_file = paste(qmc_dir,qmc_tgz,sep="")
+  } else if (Sys.info()[['sysname']] == "Darwin") {
+
+               qmc_dir <- paste(path.expand("~"),"/QuasiMC/",sep="")
+               qmc_tgz <- "QuasiMC_Mac.tgz"
+               qmc_file <- paste(qmc_dir,qmc_tgz,sep="")
 
                if(!file.exists(qmc_dir)){
-                        dir.create(qmc_dir)
-                        message(paste("Created the directory :",qmc_dir))
+                  dir.create(qmc_dir)
+                  message(paste("Created the directory :",qmc_dir))
                }
 
-               if(proxy)utils::setInternet2(TRUE)
-
                if(file.exists(qmc_file)){
                         message("Updating existing QuasiMC installation.")
                         unlink(qmc_file)
@@ -68,3 +66,4 @@ installQuasiMC <- function(proxy=FALSE){
 	       stop("QuasiMC is (currently) available for Windows and Mac OS X only.")
 	}
 }
+
